{% extends "admin/change_form.html" %}
{% load i18n %}

{% block form_top %}
  {% if not is_popup %}
    <p>{% blocktrans %}Please check KEY and NAME fields. No changes are possible after saving.{% endblocktrans %}</p>
  {% else %}
    <p></p>
  {% endif %}
{% endblock %}