"""Module allowing dynamically to create and further on to edit via django-admin settings"""

# About
__author__ = "Vadym Zabiiaka"
__email__ = "v.zabiiaka@gmail.com"
__program__ = "django-stored-settings"
__version__ = "0.1.0"